pub struct MeshFaceScalarQuantity { /* private fields */ }Expand description
A face scalar quantity on a surface mesh.
Implementations
Sourceimpl MeshFaceScalarQuantity
impl MeshFaceScalarQuantity
Sourcepub fn new(
name: impl Into<String>,
structure_name: impl Into<String>,
values: Vec<f32>,
) -> Self
pub fn new( name: impl Into<String>, structure_name: impl Into<String>, values: Vec<f32>, ) -> Self
Creates a new face scalar quantity.
Sourcepub fn colormap_name(&self) -> &str
pub fn colormap_name(&self) -> &str
Gets the colormap name.
Sourcepub fn set_colormap(&mut self, name: impl Into<String>)
pub fn set_colormap(&mut self, name: impl Into<String>)
Sets the colormap name.
Sourcepub fn compute_vertex_colors(
&self,
faces: &[Vec<u32>],
num_vertices: usize,
colormap: &ColorMap,
) -> Vec<Vec4>
pub fn compute_vertex_colors( &self, faces: &[Vec<u32>], num_vertices: usize, colormap: &ColorMap, ) -> Vec<Vec4>
Computes vertex colors by expanding face values to all vertices of each face. For each vertex, uses the color of the last face it belongs to.
Sourcepub fn build_egui_ui(&mut self, ui: &mut Ui) -> bool
pub fn build_egui_ui(&mut self, ui: &mut Ui) -> bool
Builds the egui UI for this quantity.