pub struct VolumeGridCellScalarQuantity { /* private fields */ }Expand description
A scalar quantity defined at grid cells.
Implementations
Sourceimpl VolumeGridCellScalarQuantity
impl VolumeGridCellScalarQuantity
Sourcepub fn new(
name: impl Into<String>,
structure_name: impl Into<String>,
values: Vec<f32>,
cell_dim: UVec3,
bound_min: Vec3,
bound_max: Vec3,
) -> Self
pub fn new( name: impl Into<String>, structure_name: impl Into<String>, values: Vec<f32>, cell_dim: UVec3, bound_min: Vec3, bound_max: Vec3, ) -> Self
Creates a new cell scalar quantity.
Sourcepub fn set_color_map(&mut self, name: impl Into<String>) -> &mut Self
pub fn set_color_map(&mut self, name: impl Into<String>) -> &mut Self
Sets the color map name.
Sourcepub fn data_range(&self) -> (f32, f32)
pub fn data_range(&self) -> (f32, f32)
Gets the data range.
Sourcepub fn set_data_range(&mut self, min: f32, max: f32) -> &mut Self
pub fn set_data_range(&mut self, min: f32, max: f32) -> &mut Self
Sets the data range.
Sourcepub fn gridcube_dirty(&self) -> bool
pub fn gridcube_dirty(&self) -> bool
Returns whether the gridcube needs GPU re-init.
Sourcepub fn gridcube_render_data(&self) -> Option<&GridcubeRenderData>
pub fn gridcube_render_data(&self) -> Option<&GridcubeRenderData>
Returns the gridcube render data.
Sourcepub fn gridcube_render_data_mut(&mut self) -> Option<&mut GridcubeRenderData>
pub fn gridcube_render_data_mut(&mut self) -> Option<&mut GridcubeRenderData>
Returns a mutable reference to the gridcube render data.
Sourcepub fn set_gridcube_render_data(&mut self, data: GridcubeRenderData)
pub fn set_gridcube_render_data(&mut self, data: GridcubeRenderData)
Sets the gridcube render data.
Sourcepub fn init_pick_resources(
&mut self,
device: &Device,
pick_bind_group_layout: &BindGroupLayout,
camera_buffer: &Buffer,
global_start: u32,
)
pub fn init_pick_resources( &mut self, device: &Device, pick_bind_group_layout: &BindGroupLayout, camera_buffer: &Buffer, global_start: u32, )
Initializes pick resources for this cell scalar quantity.
Sourcepub fn pick_bind_group(&self) -> Option<&BindGroup>
pub fn pick_bind_group(&self) -> Option<&BindGroup>
Returns the pick bind group, if initialized.
Sourcepub fn update_pick_uniforms(
&self,
queue: &Queue,
model: [[f32; 4]; 4],
cube_size_factor: f32,
)
pub fn update_pick_uniforms( &self, queue: &Queue, model: [[f32; 4]; 4], cube_size_factor: f32, )
Updates the pick uniform buffer with current model transform and cube size factor.
Sourcepub fn num_pick_elements(&self) -> u32
pub fn num_pick_elements(&self) -> u32
Returns the number of pick elements (= number of gridcube instances).
Sourcepub fn pick_total_vertices(&self) -> u32
pub fn pick_total_vertices(&self) -> u32
Returns the total vertices for the pick draw call.
Sourcepub fn build_egui_ui(&mut self, ui: &mut Ui, colormap_names: &[&str])
pub fn build_egui_ui(&mut self, ui: &mut Ui, colormap_names: &[&str])
Builds egui UI for this quantity.