pub struct CellSliceResult {
pub vertices: Vec<Vec3>,
pub interpolation: Vec<(u32, u32, f32)>,
}Expand description
Result of slicing a volumetric cell with a plane. Can produce 0, 3, 4, 5, or 6 intersection points forming a convex polygon.
Fields
vertices: Vec<Vec3>Intersection points (vertices of the slice polygon)
interpolation: Vec<(u32, u32, f32)>Interpolation data for vertex attributes.
Each entry is (vert_a, vert_b, t) where result = lerp(a, b, t)
Implementations
Sourceimpl CellSliceResult
impl CellSliceResult
Sourcepub fn has_intersection(&self) -> bool
pub fn has_intersection(&self) -> bool
Returns true if the slice produced a valid polygon.