pub struct CameraView { /* private fields */ }Expand description
A camera view structure for visualizing camera poses.
Implementations
Sourceimpl CameraView
impl CameraView
Sourcepub fn new(name: impl Into<String>, params: CameraParameters) -> Self
pub fn new(name: impl Into<String>, params: CameraParameters) -> Self
Creates a new camera view from camera parameters.
Sourcepub fn from_look_at(
name: impl Into<String>,
position: Vec3,
look_at: Vec3,
up: Vec3,
fov_vertical_degrees: f32,
aspect_ratio: f32,
) -> Self
pub fn from_look_at( name: impl Into<String>, position: Vec3, look_at: Vec3, up: Vec3, fov_vertical_degrees: f32, aspect_ratio: f32, ) -> Self
Creates a camera view with position and look direction.
Sourcepub fn params(&self) -> &CameraParameters
pub fn params(&self) -> &CameraParameters
Gets the camera parameters.
Sourcepub fn set_params(&mut self, params: CameraParameters) -> &mut Self
pub fn set_params(&mut self, params: CameraParameters) -> &mut Self
Updates the camera parameters.
Sourcepub fn widget_focal_length(&self) -> f32
pub fn widget_focal_length(&self) -> f32
Gets the widget focal length (distance from camera origin to frame).
Sourcepub fn set_widget_focal_length(
&mut self,
length: f32,
is_relative: bool,
) -> &mut Self
pub fn set_widget_focal_length( &mut self, length: f32, is_relative: bool, ) -> &mut Self
Sets the widget focal length.
Sourcepub fn widget_thickness(&self) -> f32
pub fn widget_thickness(&self) -> f32
Gets the widget thickness (line/sphere radius relative to focal length).
Sourcepub fn set_widget_thickness(&mut self, thickness: f32) -> &mut Self
pub fn set_widget_thickness(&mut self, thickness: f32) -> &mut Self
Sets the widget thickness.
Sourcepub fn needs_reinit(&self, length_scale: f32) -> bool
pub fn needs_reinit(&self, length_scale: f32) -> bool
Returns true if geometry needs to be (re-)initialized because length_scale changed.
Sourcepub fn init_render_data(
&mut self,
device: &Device,
bind_group_layout: &BindGroupLayout,
camera_buffer: &Buffer,
queue: &Queue,
length_scale: f32,
)
pub fn init_render_data( &mut self, device: &Device, bind_group_layout: &BindGroupLayout, camera_buffer: &Buffer, queue: &Queue, length_scale: f32, )
Initializes GPU render data.
Sourcepub fn render_data(&self) -> Option<&CurveNetworkRenderData>
pub fn render_data(&self) -> Option<&CurveNetworkRenderData>
Returns the render data if available.
Sourcepub fn take_fly_to_request(&mut self) -> bool
pub fn take_fly_to_request(&mut self) -> bool
Returns true if the user has requested to fly to this camera view. The flag is automatically cleared after reading.
Sourcepub fn build_egui_ui(&mut self, ui: &mut Ui)
pub fn build_egui_ui(&mut self, ui: &mut Ui)
Builds the egui UI for this camera view.